@@ -1,8 +1,9 @@
 """Experimental agent tools."""
 
-from .terminal import Terminal, TerminalTool
+from .terminal import SafeTerminalChain, Terminal, TerminalTool
 
 __all__ = [
     "Terminal",
     "TerminalTool",
+    "SafeTerminalChain",
 ]
