@@ -1,10 +1,13 @@
 """Terminal with persistent shell between commands."""
 
 from . import patchers  # noqa: F401
+from .safety import SafeTerminalChain, TerminalToolChain
 from .terminal import Terminal
 from .tool import TerminalTool
 
 __all__ = [
     "Terminal",
     "TerminalTool",
+    "TerminalToolChain",
+    "SafeTerminalChain",
 ]
